<?php
// @codingStandardsIgnoreFile
// @codeCoverageIgnoreStart
// this is an autogenerated file - do not edit
spl_autoload_register(
    function($class) {
        static $classes = null;
        if ($classes === null) {
            $classes = array(
                'phpparser\\node\\expr\\closureuse' => '/Node/Expr/ClosureUse.php',
                'phpparser\\node\\expr\\arrayitem' => '/Node/Expr/ArrayItem.php',
                'phpparser\\node\\stmt\\staticvar' => '/Node/Stmt/StaticVar.php',
                'phpparser\\node\\scalar\\dnumber' => '/Node/Scalar/DNumber.php',
                'phpparser\\node\\scalar\\lnumber' => '/Node/Scalar/LNumber.php',
                'phpparser\\node\\scalar\\encapsedstringpart' => '/Node/Scalar/EncapsedStringPart.php',
                'phpparser\\node\\scalar\\encapsed' => '/Node/Scalar/Encapsed.php',
                'phpparser\\node\\stmt\\declaredeclare' => '/Node/Stmt/DeclareDeclare.php',
                'phpparser\\node\\stmt\\propertyproperty' => '/Node/Stmt/PropertyProperty.php',
                'phpparser\\node\\stmt\\useuse' => '/Node/Stmt/UseUse.php',
                ___CLASSLIST___
            );
        }
        $cn = strtolower($class);
        if (isset($classes[$cn])) {
            require ___BASEDIR___$classes[$cn];
        }
    },
    ___EXCEPTION___,
    ___PREPEND___
);
// @codeCoverageIgnoreEnd
